//
// "$Id$"
//
// Resize box test program for the Fast Light Tool Kit (FLTK).
//
// Copyright 1998-2010 by Bill Spitzak and others.
//
// This library is free software. Distribution and use rights are outlined in
// the file "COPYING" which should have been included with this file.  If this
// file is missing or damaged, see the license at:
//
//     http://www.fltk.org/COPYING.php
//
// Please report all bugs and problems on the following page:
//
//     http://www.fltk.org/str.php
//

#define W1 (big ? 60 : 35)
#define B 0
#define W3 (5*W1+6*B)

#include <FL/Fl.H>
#include <FL/Fl_Box.H>
#include <FL/Fl_Double_Window.H>
#include <FL/Fl_Radio_Button.H>
#include <FL/fl_draw.H>
#include <FL/fl_message.H>
#include <FL/Enumerations.H>

Fl_Double_Window *window;
Fl_Box *box;

int big = 0;

int X1 = W1;
int X3 = W1 + W3 + W1;
int X5 = W1 + W3 + W1 + W3 + W1;
int X6 = W1 + W3 + W1 + W3 + W1 + W1;
int X7 = W1 + W3 + W1 + W3 + W1 + W3;

class Resizebox : public Fl_Group
{
public:
  Resizebox(int X, int Y, int W, int H, const char* T);
  Fl_Box *m_box;
};
  
Resizebox::Resizebox(int X, int Y, int W, int H, const char* T)
: Fl_Group(X, Y, W, H, T)
{
  this->align(FL_ALIGN_TOP_LEFT);
  this->box(FL_UP_BOX);
  Fl_Box *n;
  for (int x = 0; x < 4; x++) {
    for (int y = 0; y < 4; y++) {
      if ((x == 1 || x == 2) && (y == 1 || y == 2))
        continue;
      n = new Fl_Box(FL_FRAME_BOX,X+x*(B+W1)+B,Y+y*(B+W1)+B,W1,W1,0);
      n->color(x+y+8);
    }
  }
  n = new Fl_Box(FL_FRAME_BOX,X+B,Y+4*W1+5*B,4*W1+3*B,W1,0);
  n->color(12);
  n = new Fl_Box(FL_FRAME_BOX,X+4*W1+5*B,Y+B,W1,5*W1+4*B,0);
  n->color(13);

  m_box = new Fl_Box(FL_FRAME_BOX,X+W1+B+B,Y+W1+B+B,2*W1+B,2*W1+B,0);
  m_box->color(FL_YELLOW);
  m_box->label("resizable");

  this->end();
  this->resizable(m_box);
}

class Harrow : public Fl_Box
{
public:
  Harrow(int X, int Y, int W, int H, const char* T) : Fl_Box(X, Y, W, H, T) {
    align(FL_ALIGN_BOTTOM);
    box(FL_NO_BOX);
    color(FL_WHITE);
  }

  void draw() {
    Fl_Color old = fl_color();
    int dx = 5, dy = 4;
    int my = y() + h()/2;
    fl_rectf(x(), y(), w(), h(), FL_WHITE);
    fl_color(FL_BLACK);
    fl_polygon(x(), my, x()+dx, my-dy, x()+dx, my+dy);
    fl_line(x()+dx, my, x()+w()-dx, my);
    fl_polygon(x()+w(), my, x()+w()-dx, my+dy, x()+w()-dx, my-dy);
    fl_color(old);
  }
};

class Varrow : public Fl_Box
{
public:
  Varrow(int X, int Y, int W, int H, const char* T) : Fl_Box(X, Y, W, H, T) {
    align(FL_ALIGN_RIGHT);
    box(FL_NO_BOX);
    color(FL_WHITE);
  }

  void draw() {
    Fl_Color old = fl_color();
    int dx = 4, dy = 5;
    int mx = x() + w()/2;
    fl_rectf(x(), y(), w(), h(), FL_WHITE);
    fl_color(FL_BLACK);
    fl_polygon(mx-dx, y()+dy, mx, y(), mx+dx, y()+dy);
    fl_line(mx, y()+dy, mx, y()+h()-dy);
    fl_polygon(mx-dx, y()+h()-dy, mx+dx, y()+h()-dy, mx, y()+h());
    fl_color(old);
  }
};

class Resizables : public Fl_Group
{
public:
  Resizables(int X, int Y, int W, int H, const char *T=0);
  Resizebox *TL, *TR, *BL, *BR;
  Harrow *LH, *RH;
  Varrow *TV, *BV;
};

Resizables::Resizables(int X, int Y, int W, int H, const char *T)
: Fl_Group(X, Y, W, H, T)
{
  this->box(FL_UP_BOX);
  this->color(FL_WHITE);

  TL = new Resizebox(X+X1, Y+X1, W3, W3, "Original Size");
  TL->resizable(0);
  TR = new Resizebox(X+X3, Y+X1, W3, W3, "Horizontally Resized");
  BL = new Resizebox(X+X1, Y+X3, W3, W3, "Vertically Resized");
  BR = new Resizebox(X+X3, Y+X3, W3, W3, "Horizontally and Vertically Resized");

  Fl_Group *LG = new Fl_Group(X+X1, Y+X3+W3, W3, W3);
  {
    LG->box(FL_NO_BOX);
    LG->color(FL_WHITE);
    LH = new Harrow(BL->m_box->x(), LG->y(), BL->m_box->w(), W1,
                    "Initial\nwidth");
    LG->resizable(LH);
    LG->end();
  }
  Fl_Group *RG = new Fl_Group(X+X3, Y+X3+W3, W3, W3);
  {
    RG->box(FL_NO_BOX);
    RG->color(FL_WHITE);
    LH = new Harrow(BR->m_box->x(), LG->y(), BL->m_box->w(), W1,
                    "Stretched\nwidth");
    RG->resizable(LH);
    RG->end();
  }

  Fl_Group *TG = new Fl_Group(X+X3+W3, Y+X1, W1, W3);
  {
    TG->box(FL_NO_BOX);
    TG->color(FL_WHITE);
    TV = new Varrow(TG->x(), TR->m_box->y(), W1, TR->m_box->h(),
                    "Initial\nheight");
    TG->resizable(TV);
    TG->end();
  }
  Fl_Group *BG = new Fl_Group(X+X3+W3, Y+X3, W1, W3);
  {
    BG->box(FL_NO_BOX);
    BG->color(FL_WHITE);
    BV = new Varrow(BG->x(), BR->m_box->y(), W1, BR->m_box->h(),
                    "Stretched\nheight");
    BG->resizable(BV);
    BG->end();
  }

  this->resizable(BR);
  this->end();
}

int main(int argc, char **argv) {
  window = new Fl_Double_Window(X7, X7, "resizables");
  window->color(FL_WHITE);
  Resizables *resizables = new Resizables(0, 0, X7, X7);
  window->end();
  window->resizable(resizables);
  window->size_range(X7, X7);
  window->show(argc, argv);
  return Fl::run();
}

//
// End of "$Id$".
//
