//
// "$Id$"
//
// Resize example for the Fast Light Tool Kit (FLTK) documentation.
//
// Copyright 1998-2020 by Bill Spitzak and others.
//
// This library is free software. Distribution and use rights are outlined in
// the file "COPYING" which should have been included with this file.  If this
// file is missing or damaged, see the license at:
//
//     http://www.fltk.org/COPYING.php
//
// Please report all bugs and problems on the following page:
//
//     http://www.fltk.org/str.php
//

#define L0 (0*35)
#define L1 (1*35)
#define L2 (2*35)
#define L3 (3*35)
#define L4 (4*35)
#define L5 (5*35)
#define L6 (6*35)
#define L7 (7*35)

#include <FL/Fl.H>
#include <FL/Fl_Box.H>
#include <FL/Fl_Double_Window.H>
#include <FL/Fl_Radio_Button.H>
#include <FL/fl_draw.H>
#include <FL/fl_message.H>
#include <FL/Enumerations.H>
#include "arrows.h"

Fl_Double_Window *window;
Fl_Box *box;

int big = 0;

class Resizebox : public Fl_Group
{
public:
  Resizebox(int X, int Y, int W, int H, const char* T);
  Fl_Box *m_box;
};
  
Resizebox::Resizebox(int X, int Y, int W, int H, const char* T)
: Fl_Group(X, Y, W, H, T)
{
  this->align(FL_ALIGN_TOP_LEFT);
  this->box(FL_UP_BOX);

  Fl_Box *b;
  b = new Fl_Box(FL_FRAME_BOX, X+L0, Y+L0, L1, L1, "A"); b->color(14);
  b = new Fl_Box(FL_FRAME_BOX, X+L1, Y+L0, L1, L1, "B"); b->color(9);
  b = new Fl_Box(FL_FRAME_BOX, X+L2, Y+L0, L1, L1, "C"); b->color(10);
  b = new Fl_Box(FL_FRAME_BOX, X+L3, Y+L0, L1, L1, "D"); b->color(11);
  b = new Fl_Box(FL_FRAME_BOX, X+L0, Y+L1, L1, L1, "E"); b->color(9);
  b = new Fl_Box(FL_FRAME_BOX, X+L1, Y+L1, L2, L2, "R"); b->color(3);
  b->label("resizable");
  m_box = b;
  b = new Fl_Box(FL_FRAME_BOX, X+L3, Y+L1, L1, L1, "F"); b->color(12);
  b = new Fl_Box(FL_FRAME_BOX, X+L0, Y+L2, L1, L1, "G"); b->color(10);
  b = new Fl_Box(FL_FRAME_BOX, X+L3, Y+L2, L1, L1, "H"); b->color(13);
  b = new Fl_Box(FL_FRAME_BOX, X+L0, Y+L3, L1, L1, "I"); b->color(11);
  b = new Fl_Box(FL_FRAME_BOX, X+L1, Y+L3, L1, L1, "J"); b->color(12);
  b = new Fl_Box(FL_FRAME_BOX, X+L2, Y+L3, L1, L1, "K"); b->color(13);
  b = new Fl_Box(FL_FRAME_BOX, X+L3, Y+L3, L1, L1, "L"); b->color(14);
  b = new Fl_Box(FL_FRAME_BOX, X+L0, Y+L4, L4, L1, "M"); b->color(12);
  b = new Fl_Box(FL_FRAME_BOX, X+L4, Y+L0, L1, L5, "N"); b->color(13);

  this->end();
  this->resizable(m_box);
}

class Resizables : public Fl_Group
{
public:
  Resizables(int X, int Y, int W, int H, const char *T=0);
  Resizebox *TL, *TR, *BL, *BR;
  Harrow *LH, *RH;
  Varrow *TV, *BV;
};

Resizables::Resizables(int X, int Y, int W, int H, const char *T)
: Fl_Group(X, Y, W, H, T)
{
  this->box(FL_UP_BOX);
  this->color(FL_WHITE);

  TL = new Resizebox(X+L1, Y+L1, L5, L5, "Original Size");
  TL->resizable(0);
  TR = new Resizebox(X+L7, Y+L1, L5, L5, "Horizontally Resized");
  BL = new Resizebox(X+L1, Y+L7, L5, L5, "Vertically Resized");
  BR = new Resizebox(X+L7, Y+L7, L5, L5, "Horizontally and Vertically Resized");

  Fl_Group *LG = new Fl_Group(X+L1, Y+L6+L6, L5, L3);
  {
    LG->box(FL_NO_BOX);
    LG->color(FL_WHITE);
    LH = new Harrow(BL->m_box->x(), LG->y(), BL->m_box->w(), L1,
                    "Initial\nwidth");
    LG->resizable(LH);
    LG->end();
  }
  Fl_Group *RG = new Fl_Group(X+L7, Y+L6+L6, L5, L3);
  {
    RG->box(FL_NO_BOX);
    RG->color(FL_WHITE);
    LH = new Harrow(BR->m_box->x(), LG->y(), BL->m_box->w(), L1,
                    "Resized\nwidth");
    RG->resizable(LH);
    RG->end();
  }

  Fl_Group *TG = new Fl_Group(X+L7+L5, Y+L1, L2, L5);
  {
    TG->box(FL_NO_BOX);
    TG->color(FL_WHITE);
    TV = new Varrow(TG->x(), TR->m_box->y(), L1, TR->m_box->h(),
                    "Initial\nheight");
    TG->resizable(TV);
    TG->end();
  }
  Fl_Group *BG = new Fl_Group(X+L7+L5, Y+L5, L2, L5);
  {
    BG->box(FL_NO_BOX);
    BG->color(FL_WHITE);
    BV = new Varrow(BG->x(), BR->m_box->y(), L1, BR->m_box->h(),
                    "Resized\nheight");
    BG->resizable(BV);
    BG->end();
  }

  this->resizable(BR);
  this->end();
}

int main(int argc, char **argv) {
  window = new Fl_Double_Window(L6+L6+L4, L6+L6+L3, "resize-example1");
  window->color(FL_WHITE);
  Resizables *resizables = new Resizables(0, 0, L6+L6+L4, L6+L6+L3);
  window->end();
  window->resizable(resizables);
  window->size_range(L6+L6+L4, L6+L6+L3);
  window->show(argc, argv);
  return Fl::run();
}

//
// End of "$Id$".
//

