//
// "$Id$"
//
// Resize example for the Fast Light Tool Kit (FLTK) documentation.
//
// Copyright 1998-2020 by Bill Spitzak and others.
//
// This library is free software. Distribution and use rights are outlined in
// the file "COPYING" which should have been included with this file.  If this
// file is missing or damaged, see the license at:
//
//     http://www.fltk.org/COPYING.php
//
// Please report all bugs and problems on the following page:
//
//     http://www.fltk.org/str.php
//

#define WW (10+30+10+140+10)
#define W1 (1*35)
#define W2 (W1+WW)
#define W3 (W2+W1)
#define W4 (W3+WW)
#define W5 (W4+WW)
#define HH (10+30+10+30+10)
#define H1 (1+35)
#define H2 (H1+HH)
#define H3 (H2+H1)
#define H4 (H3+HH)
#define H5 (H4+H1+H1+H1)

#include <FL/Fl.H>
#include <FL/Fl_Box.H>
#include <FL/Fl_Double_Window.H>
#include <FL/Fl_Button.H>
#include <FL/Enumerations.H>
#include "arrows.h"

Fl_Double_Window *window;

class ResizeDialog : public Fl_Group
{
public:
  ResizeDialog(int X, int Y, int W, int H, const char* T=0);
  Fl_Box *m_icon;
  Fl_Box *m_message;
  Fl_Button *m_button;
};
  
ResizeDialog::ResizeDialog(int X, int Y, int W, int H, const char* T)
: Fl_Group(X, Y, W, H, T)
{
  this->align(FL_ALIGN_TOP_LEFT);
  this->box(FL_UP_BOX);

  m_icon = new Fl_Box(X+10, Y+10, 30, 30, "!");
  m_icon->box(FL_DOWN_BOX);
  m_message = new Fl_Box(X+50, Y+10, 140, 30, "Out of Memory Error");
  m_message->box(FL_DOWN_BOX);
  m_message->color(FL_YELLOW);
  m_button = new Fl_Button(X+140, Y+50, 50, 30, "Darn!");

  this->end();
  this->resizable(m_message);
}

class Resizables : public Fl_Group
{
public:
  Resizables(int X, int Y, int W, int H, const char *T=0);
  ResizeDialog *TL, *TR, *BL, *BR;
  Harrow *LH, *RH;
  Varrow *TV, *BV;
};

Resizables::Resizables(int X, int Y, int W, int H, const char *T)
: Fl_Group(X, Y, W, H, T)
{
  this->box(FL_UP_BOX);
  this->color(FL_WHITE);

  TL = new ResizeDialog(X+W1, Y+H1, WW, HH, "Original Size");
  TL->resizable(0);
  TR = new ResizeDialog(X+W3, Y+H1, WW, HH, "Horizontally Resized");
  BL = new ResizeDialog(X+W1, Y+H3, WW, HH, "Vertically Resized");
  BR = new ResizeDialog(X+W3, Y+H3, WW, HH, "Horizontally and Vertically Resized");

  Fl_Group *LG = new Fl_Group(X+W1, Y+H4, WW, H2);
  {
    LG->box(FL_NO_BOX);
    LG->color(FL_WHITE);
    LH = new Harrow(BL->m_message->x(), LG->y(), BL->m_message->w(), H1,
                    "Initial\nwidth");
    LG->resizable(LH);
    LG->end();
  }
  Fl_Group *RG = new Fl_Group(X+W3, Y+H4, WW, H2);
  {
    RG->box(FL_NO_BOX);
    RG->color(FL_WHITE);
    LH = new Harrow(BR->m_message->x(), LG->y(), BL->m_message->w(), H1,
                    "Resized\nwidth");
    RG->resizable(LH);
    RG->end();
  }

  Fl_Group *TG = new Fl_Group(X+W4, Y+H1, WW, HH);
  {
    TG->box(FL_NO_BOX);
    TG->color(FL_WHITE);
    TV = new Varrow(TG->x(), TR->m_message->y(), W1, TR->m_message->h(),
                    "Initial\nheight");
    TG->resizable(TV);
    TG->end();
  }
  Fl_Group *BG = new Fl_Group(X+W4, Y+H3, WW, HH);
  {
    BG->box(FL_NO_BOX);
    BG->color(FL_WHITE);
    BV = new Varrow(BG->x(), BR->m_message->y(), W1, BR->m_message->h(),
                    "Resized\nheight");
    BG->resizable(BV);
    BG->end();
  }

  this->resizable(BR);
  this->end();
}

int main(int argc, char **argv) {
  window = new Fl_Double_Window(W5, H5, "resize-example2b");
  window->color(FL_WHITE);
  Resizables *resizables = new Resizables(0, 0, W5, H5);
  window->end();
  window->resizable(resizables);
  window->size_range(W5, H5);
  window->show(argc, argv);
  return Fl::run();
}

//
// End of "$Id$".
//

