//
// "$Id$"
//
// Resize example for the Fast Light Tool Kit (FLTK) documentation.
//
// Copyright 1998-2020 by Bill Spitzak and others.
//
// This library is free software. Distribution and use rights are outlined in
// the file "COPYING" which should have been included with this file.  If this
// file is missing or damaged, see the license at:
//
//     http://www.fltk.org/COPYING.php
//
// Please report all bugs and problems on the following page:
//
//     http://www.fltk.org/str.php
//

#include <FL/Fl.H>
#include <FL/Fl_Box.H>
#include <FL/Fl_Double_Window.H>
#include <FL/Fl_Group.H>
#include "arrows.h"

Fl_Double_Window *window = 0;

class Simplex : public Fl_Group
{
public:
  Simplex(int X, int Y, int W, int H, const char* T=0);
  Fl_Box *m_button1, *m_input1, *m_button2, *m_input2;
};

Simplex::Simplex(int X, int Y, int W, int H, const char* T)
: Fl_Group(X, Y, W, H, T)
{
  this->box(FL_UP_BOX);
  Fl_Group *group = new Fl_Group(X+10, Y+10, 240, 45);
  group->box(FL_NO_BOX);
  m_button1 = new Fl_Box(X+20, Y+20, 40, 25, "btn");
  m_button1->box(FL_UP_BOX);
  m_input1  = new Fl_Box(X+70, Y+20, 50, 25, "input");
  m_input1->box(FL_UP_BOX);
  m_button2 = new Fl_Box(X+140, Y+20, 40, 25, "btn");
  m_button2->box(FL_UP_BOX);
  m_input2  = new Fl_Box(X+190, Y+20, 50, 25, "input");
  m_input2->box(FL_UP_BOX);
  m_input2->color(FL_YELLOW);
  group->resizable(m_input2);
  group->end();
  this->resizable(group);
  this->end();
}

class Resizables : public Fl_Group
{
public:
  Resizables(int X, int Y, int W, int H, const char* T=0);
  Simplex *TL, *TR;
  Harrow *LH, *RH;
};

Resizables::Resizables(int X, int Y, int W, int H, const char* T)
: Fl_Group(X, Y, W, H, T)
{
  TL = new Simplex(X+35, Y+35, 260, 65, "Original");
  TL->align(FL_ALIGN_TOP_LEFT);

  TR = new Simplex(X+320, Y+35, 260, 65, "Horizonally Resized");
  TR->align(FL_ALIGN_TOP_LEFT);

  Fl_Group *LG = new Fl_Group(X+35, Y+100, 260, 70);
  {
    LG->box(FL_NO_BOX);
    LG->color(FL_WHITE);
    LH = new Harrow(TL->m_input2->x(), LG->y(), TL->m_input2->w(), 35,
                    "Initial\nwidth");
    LG->resizable(LH);
    LG->end();
  }
  Fl_Group *RG = new Fl_Group(X+320, Y+100, 260, 70);
  {
    RG->box(FL_NO_BOX);
    RG->color(FL_WHITE);
    RH = new Harrow(TR->m_input2->x(), RG->y(), TR->m_input2->w(), 35,
                    "Resized\nwidth");
    RG->resizable(RH);
    RG->end();
  }
  this->resizable(TR);
  this->end();
}


int main(int argc, char **argv)
{
  window = new Fl_Double_Window(620, 200, "resize-example3a");
  window->color(FL_WHITE);
  Resizables *resizables = new Resizables(0, 0, 620, 200);
  window->end();
  window->resizable(resizables);
  window->size_range(620, 200);
  window->show(argc, argv);
  return Fl::run(); 
}

//
// End of "$Id$".
//

